View source: R/gsSurvCalendar.R
| gsSurvCalendar | R Documentation |
This is like gsSurv(), but the timing of analyses is specified in
calendar time units.
Information fraction is computed from the input rates and the calendar times.
Spending can be based on information fraction as in Lan and DeMets (1983) or
calendar time units as in Lan and DeMets (1989).
gsSurvCalendar(
test.type = 4,
alpha = 0.025,
sided = 1,
beta = 0.1,
astar = 0,
sfu = gsDesign::sfHSD,
sfupar = -4,
sfl = gsDesign::sfHSD,
sflpar = -2,
sfharm = gsDesign::sfHSD,
sfharmparam = -2,
calendarTime = c(12, 24, 36),
spending = c("information", "calendar"),
lambdaC = log(2)/6,
hr = 0.6,
hr0 = 1,
eta = 0,
etaE = NULL,
gamma = 1,
R = 12,
S = NULL,
minfup = 18,
ratio = 1,
r = 18,
tol = .Machine$double.eps^0.25,
testUpper = TRUE,
testLower = TRUE,
testHarm = TRUE,
method = c("LachinFoulkes", "Schoenfeld", "Freedman", "BernsteinLagakos")
)
test.type |
|
alpha |
Type I error rate. Default is 0.025 since 1-sided testing is default. |
sided |
|
beta |
Type II error rate. Default is 0.10 (90% power); |
astar |
Total spending for the lower (test.type 5 or 6) or harm
(test.type 7 or 8) bound under the null hypothesis. Default is 0.
For |
sfu |
A spending function or a character string indicating a boundary
type (that is, “WT” for Wang-Tsiatis bounds, “OF” for
O'Brien-Fleming bounds and “Pocock” for Pocock bounds). For
one-sided and symmetric two-sided testing is used to completely specify
spending ( |
sfupar |
Real value, default is |
sfl |
Specifies the spending function for lower boundary crossing
probabilities when asymmetric, two-sided testing is performed
( |
sflpar |
Real value, default is |
sfharm |
A spending function for the harm bound, used with
|
sfharmparam |
Real value, default is |
calendarTime |
Vector of increasing positive numbers with calendar times of analyses. Time 0 is start of randomization. |
spending |
Select between calendar-based spending and information-based spending. |
lambdaC |
Scalar, vector or matrix of event hazard rates for the control group; rows represent time periods while columns represent strata; a vector implies a single stratum. Note that rates corresponding the final time period are extended indefinitely. |
hr |
Hazard ratio (experimental/control) under the alternate hypothesis
(scalar, > 0, must differ from |
hr0 |
Hazard ratio (experimental/control) under the null hypothesis
(scalar, > 0, must differ from |
eta |
Scalar, vector or matrix of dropout hazard rates for the control group; rows represent time periods while columns represent strata; if entered as a scalar, rate is constant across strata and time periods; if entered as a vector, rates are constant across strata. |
etaE |
Matrix dropout hazard rates for the experimental group specified
in like form as |
gamma |
A scalar, vector or matrix of rates of entry by time period (rows) and strata (columns); if entered as a scalar, rate is constant across strata and time periods; if entered as a vector, rates are constant across strata. |
R |
A scalar or vector of durations of time periods for
recruitment rates specified in rows of |
S |
A scalar or vector of durations of piecewise constant event rates
specified in rows of |
minfup |
A non-negative scalar less than the maximum value
in |
ratio |
Randomization ratio of experimental treatment divided by control; normally a scalar, but may be a vector with length equal to number of strata. |
r |
Integer value (>= 1 and <= 80) controlling the number of numerical
integration grid points. Default is 18, as recommended by Jennison and
Turnbull (2000). Grid points are spread out in the tails for accurate
probability calculations. Larger values provide more grid points and greater
accuracy but slow down computation. Jennison and Turnbull (p. 350) note an
accuracy of |
tol |
Tolerance for error passed to the |
testUpper |
Indicator of which analyses should include an upper
(efficacy) bound.
A single value of |
testLower |
Indicator of which analyses should include a lower
(futility) bound.
A single value of |
testHarm |
Indicator of which analyses should include a harm bound.
A single value of |
method |
One of |
An object of class c("gsSurv", "gsDesign") with
group sequential boundaries and expected counts at each calendar
analysis time. See gsSurv for full component details.
Lan KKG and DeMets DL (1983), Discrete Sequential Boundaries for Clinical Trials. Biometrika, 70, 659-663.
Lan KKG and DeMets DL (1989), Group Sequential Procedures: Calendar vs. Information Time. Statistics in Medicine, 8, 1191-1198.
Schoenfeld D (1981), The Asymptotic Properties of Nonparametric Tests for Comparing Survival Distributions. Biometrika, 68, 316-319.
Freedman LS (1982), Tables of the Number of Patients Required in Clinical Trials Using the Logrank Test. Statistics in Medicine, 1, 121-129.
vignette("SeqDesignSurvival", package = "gsDesign") for a
SAS PROC SEQDESIGN sample size translation example and
vignette("gsSurvPower", package = "gsDesign") for power
calculations with fixed calendar analysis assumptions.
gsSurv, gsSurvPower, gsDesign,
gsBoundSummary
# First example: while timing is calendar-based, spending is event-based
x <- gsSurvCalendar() |> toInteger()
gsBoundSummary(x)
# Second example: both timing and spending are calendar-based
# This results in less spending at interims and leaves more for final analysis
y <- gsSurvCalendar(spending = "calendar") |> toInteger()
gsBoundSummary(y)
# Note that calendar timing for spending relates to planned timing for y
# rather than timing in y after toInteger() conversion
# Values plugged into spending function for calendar time
y$usTime
# Actual calendar fraction from design after toInteger() conversion
y$T / max(y$T)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.