Skip to contents

Applies standard labels, number formats, spanners, and explanatory footnotes to a table returned by VEtable.

Usage

# S3 method for class 'gsVETable'
lt(
  data,
  ...,
  title = "Design Bounds and Operating Characteristics",
  subtitle = NULL,
  efficacy_label = c("VE", "PE"),
  time_decimals = 1,
  efficacy_decimals = 2,
  spending_decimals = 4
)

Arguments

data

A gsVETable object returned by VEtable.

...

Additional arguments passed to lt.

title

Table title.

subtitle

Optional table subtitle.

efficacy_label

Whether to label efficacy as vaccine efficacy ("VE") or prevention efficacy ("PE").

time_decimals

Number of decimal places for analysis time.

efficacy_decimals

Number of decimal places for efficacy at the boundaries and power.

spending_decimals

Number of decimal places for alpha and beta spending.

Value

An lt_tbl object.

Examples

design <- gsSurv(
  k = 2, test.type = 4, timing = .6, ratio = 3,
  hr = .3, hr0 = .7
)
VEtable(toBinomialExact(design), ve = c(.5, .7)) |>
  lt()