Applies standard labels, number formats, spanners, and explanatory
footnotes to a table returned by VEtable.
Arguments
- data
A
gsVETableobject returned byVEtable.- ...
Additional arguments passed to
lt.- title
Table title.
- subtitle
Optional table subtitle.
- efficacy_label
Whether to label efficacy as vaccine efficacy (
"VE") or prevention efficacy ("PE").- time_decimals
Number of decimal places for analysis time.
- efficacy_decimals
Number of decimal places for efficacy at the boundaries and power.
- spending_decimals
Number of decimal places for alpha and beta spending.
Examples
design <- gsSurv(
k = 2, test.type = 4, timing = .6, ratio = 3,
hr = .3, hr0 = .7
)
VEtable(toBinomialExact(design), ve = c(.5, .7)) |>
lt()